mclustboot.intern: MclustBootstrap with nboot = 1 and the same output as Mclust

mclustboot.internR Documentation

MclustBootstrap with nboot = 1 and the same output as Mclust

Description

MclustBootstrap with nboot = 1 and the same output as Mclust

Usage

mclustboot.intern(don, G = NULL, modelNames = NULL, verbose = FALSE)

Arguments

don

matrix, or data frame

G

An integer vector specifying the numbers of mixture components

modelNames

A vector of character strings indicating the models to be fitted

verbose

A logical controlling if a text progress bar is displayed


clusterMI documentation built on April 3, 2026, 5:06 p.m.